%% part 0: the documentation, extremely useful!

doc 

%% part 1: the plot command and properties via GUI

x = 1:10;
y = x.^2;

plot(x,y); % using all default values

%% introduction examples

x = linspace(0,2*pi);
y1 = sin(x);

figure;
plot(x, y1);

%% add a second line

y2 = cos(x);

hold all; % to keep the old plot and add new one in the figure
plot(x,y2);

%% manipulate graph with the GUI

% label axis
% legend
% grid on
% title
% fonts
% export setup
% generate m-file
% ...


%% save settings

figure;
plot(x,y1);

%% reuse saved settings

x = linspace(0,1);
y = exp(x);

createfigure(x, y);


%% part 2: the MATLAB graphics as objects

% create a figure object with default parameters (no arguments) and 
% return a handle for this object
f = figure(); 

%% the graphics objects are organized in a hierarchical way

% create a axes object with default parameters (no arguments) and 
% return a handle for this object
a = axes();

%% tree

get(f,'Children')
get(a, 'Parent')

%% 
x = 1:10;
y = x.^2;

% create a line object with default parameters (no arguments) and 
% return a handle for this object
l = line(x,y);

%%

% create text objects for the x and y axis label and 
% return a handle for this object
t1 = xlabel('x');
t2 = ylabel('y');

%% object properties

% to see properties of our line (best, use the help browser)
set(l)

%% 

% to see obtions for a specific property
set(l,'Marker')

%% object properties are altered via set() and get()

% 
set(l,'Marker','o')

%% 

% alter many properties at once
set(l,'MarkerSize',8,'LineStyle','--','LineWidth',3)

%% many, many properties can be set this way

set(a,'FontSize',16,'LineWidth',2,'XLim',[0,11],'YLim',[0 120],...
    'XGrid','on','YGrid','on');

%% 

set(a,'XLabel',text('String', 'x'));

%% we can use get() to see the properties

% handle type
get(a,'type')

%%
% all properties
get(l)

%%
% a specific
get(l,'LineWidth')


%% this approach can be used to alter any properties 

% - important to understand the organization of graphic objects
% - in practice, many shortcuts available to do things more efficiently

%% here the complete example above
x = 1:10;
y = x.^2;

f = figure(); 
a = axes();
l = line(x,y);
t1 = xlabel('x','FontSize',16);
t2 = ylabel('y','FontSize',16);
set(a,'FontSize',16,'LineWidth',2,'XLim',[0,11],'YLim',[0 120],...
    'XGrid','on','YGrid','on');
set(l,'Marker','o','MarkerSize',8,'LineStyle','--','LineWidth',3);

%% another example of this approach

% data
month = ['Jan';'Feb';'Mar';'Apr';'May';'Jun'; ...
         'Jul';'Aug';'Sep';'Oct';'Nov';'Dec'];
rainfall = [4.46 4.02 3.76 3.71 4.03 4.96 ...
            4.93 4.69 4.11 4.25 4.21 5.49];

% create objects
hf = figure;
ha = axes;
hb = bar(rainfall);

% figure setup
set(hf,'MenuBar', 'none');
set(hf,'Position', [0 0 800 400]);
set(hf, 'Color', 'w');

% axes setup
set(ha, 'Fontsize', 16);
set(ha, 'FontName', 'Courier');
set(ha, 'FontWeight', 'bold');
set(ha, 'LineWidth', 2);
set(ha, 'YLim', [0 6]);
set(ha, 'XLim', [0 13]);
set(ha, 'XTick', 1:12);
set(ha, 'XTickLabel', month);
set(ha, 'YGrid', 'on');
set(get(ha, 'Ylabel'), 'String', 'Rain [cm]', 'Fontsize', 16, ...
    'FontWeight', 'bold');
set(ha, 'Title', text('String', 'Rainfall in Aachen', ...
    'FontSize',16,'FontWeight', 'bold'));

% bar setup
set(hb,'LineWidth',2);
set(hb,'BarWidth', 1);
set(hb,'FaceColor', 'r');


%% part 3: MATLAB plotting functions

x = linspace(-pi,pi,200);
y = randn(1,1000);
u = linspace(-1,2);

figure('Position',[0 0 800 800]);
set(gcf,'Name','Some 2-d plot functions in MATLAB');

subplot(3,3,1), plot(x, sin(x), x, cos(x), 'LineWidth',2);
set(gca, 'Title', text('String', 'plot()'));
grid on;

subplot(3,3,2), bar(1:10,randn(1,10));
set(gca, 'XLim',[0 11])
set(gca, 'Title', text('String', 'bar()'));
set(gca, 'YGrid', 'on');

subplot(3,3,3), barh(1:10,randn(1,10));
set(gca, 'YLim',[0 11])
set(gca, 'Title', text('String', 'barh()'));
set(gca, 'XGrid', 'on');

subplot(3,3,4), hist(y);
set(gca, 'Title', text('String', 'hist()'));
set(gca, 'YGrid', 'on');

subplot(3,3,5), area(sin(x));
set(gca, 'Title', text('String', 'area()'));
grid on;

subplot(3,3,6), pie([1 1 1 2]);
set(gca, 'Title', text('String', 'pie()'));

subplot(3,3,7), polar(x,sin(x).^2);
set(gca, 'Title', text('String', 'polar()'));

subplot(3,3,8), scatter(randn(100,1),randn(100,1),'.');
set(gca, 'Title', text('String', 'scatter()'));
grid on;
 
subplot(3,3,9), semilogy(u, exp(u));
set(gca, 'Title', text('String', 'semilogx()'));
grid on;


%%

% of course every function comes with a lot of properties
% to change in order to create nicer graphs
doc

%%

x = -1:.05:1;
y = -2.5:.05:-.5;
[X,Y] = meshgrid(x,y);
Z = cos(3*Y - 4*X) .* sin(X.^2 + 3*Y);

figure('Position',[0 0 1000 800]);
set(gcf,'Name','more 3-d plot functions in MATLAB');

subplot(2,2,1),
mesh(X,Y,Z);
title('mesh()');

subplot(2,2,2),
surf(X,Y,Z);
title('surf()');

subplot(2,2,3),
surfc(X,Y,Z);
title('surfc()');

subplot(2,2,4),
surfl(X,Y,Z);
title('surfl()');
shading interp
colormap hot;


%%
Y = rand(4,3);

figure('Position',[0 0 1000 800]);
set(gcf,'Name','more 3-d plot functions in MATLAB');

subplot(2,2,1),
t = 0:pi/50:10*pi;
plot3(sin(t),cos(t),t,'LineWidth',3)
title('plot3()');
grid on;

subplot(2,2,2),
bar3(Y);
title('bar3()');

subplot(2,2,3),
bar3h(Y);
title('bar3h()');

subplot(2,2,4),
pie3([1 1 1 2]);
title('pie3()');

%%

% of course every function comes with a lot of properties
% to change in order to create nicer graphs
doc


%% the documentation contains many examples and how to use 
% the plotting functions

% Define 3-D arrays x, y, z, u, v, w
xmin = -7; xmax = 7;
ymin = -7; ymax = 7; 
zmin = -7; zmax = 7; 
x = linspace(xmin,xmax,30);
y = linspace(ymin,ymax,20);
z = linspace(zmin,zmax,20);
[x y z] = meshgrid(x,y,z);
u = y; v = -x; w = 0*x+1;
[cx cy cz] = meshgrid(linspace(xmin,xmax,30),...
 linspace(ymin,ymax,30),[-3 4]);
h = coneplot(x,y,z,u,v,w,cx,cy,cz,'quiver');
set(h,'color','k');
% Plot two sets of streamribbons
[sx sy sz] = meshgrid([-1 0 1],[-1 0 1],-6);
streamribbon(x,y,z,u,v,w,sx,sy,sz);
[sx sy sz] = meshgrid([1:6],[0],-6);
streamribbon(x,y,z,u,v,w,sx,sy,sz);
% Define viewing and lighting
shading interp
view(-30,10) ; axis off tight
camproj perspective; camva(66); camlookat; 
camdolly(0,0,.5,'fixtarget')
camlight


%% animation

Z = peaks;
surf(Z); 
axis([0 50 0 50 -10 10]);
N = 100;
for j=1:N
    surf(cos(2*pi*j/N).*Z); 
    axis([0 50 0 50 -10 10]);
    F(j) = getframe;
end
movie(F)


%% part 4: how to use some plotting fuction and some shortcuts

x = linspace(0,2*pi,10);
y1 = sin(x);
y2 = cos(x);

figure('Position',[0 0 600 400]);
plot(x,y1,'ro--','LineWidth',3,'MarkerSize',8);

%% gca, gcf, gco, ...

% gcf = 'get current figure'
% gca = 'get current axes'
% gco = 'get current object'

set(gca,'FontName','AvantGarde');
set(gca,'FontSize',16);

%% title, xlabel, ylabel, legend, grid, axis, legend, ...
title('Some title');
xlabel('Some x-label');
ylabel('Some y-label');
grid on;
box off;
axis([0 2*pi -1.2 1.2]);

%%
set(gca,'XTick',[0 pi/2 pi 3*pi/2 2*pi])
set(gca,'XTickLabel',{'0';'';'a';'';'2a';})

%% hold all, etc...
hold all;
plot(x,y2,'ks-.','LineWidth',3,'MarkerSize',8,'MarkerFaceColor',[.49 1 .63]);

%%
legend('sin','cos','Location','Best');

%% putting all together
x = linspace(0,2*pi,10);
y1 = sin(x);
y2 = cos(x);

figure('Position',[0 0 600 440]);
hold on;
plot(x,y1,'ro--','LineWidth',3,'MarkerSize',8);
plot(x,y2,'ks-.','LineWidth',3,'MarkerSize',8,'MarkerFaceColor',...
     [.49 1 .63]);
hold off;

set(gca,'FontName','AvantGarde');
set(gca,'FontSize',16);
title('Some title');
xlabel({'Some x-label';'with two lines'},'FontSize',14);  % properties ...
ylabel('y-label','FontSize',14);                    % ... can be added
grid on;
box off;
axis([0 2*pi -1.2 1.2]);
set(gca,'XTick',[0 pi/2 pi 3*pi/2 2*pi])
set(gca,'XTickLabel',{'0';'';'a';'';'2a';})
legend('sin','cos','Location','Best');


%% another example

figure;
contourf(peaks);

%%

axis square

%% again, alsways can use set() ...

set(gca,'XTick',[]);
set(gca,'YTick',[]);

%% colorbar

colorbar;

%% colormap

colormap winter;

%%

colormap hot;

%%

doc colormap

%% brighten

brighten(0.5)

%% h=findobj; get(h,'Type')

h = findobj('Type','patch');
set(h,'LineWidth',3)


%% exporting figures as fig, eps, pdf

% 1) File -> Save As
% 2) saveas command
% 3) exportfig command (routine can be download from MathWorks)

%% 
saveas(gcf, 'imagetitle', 'eps');

%% some practical advice

% 1) always save the graphs in MATLAB fig format additionally, 
%    in case you want to make changes later 
% 2) Use vector graphics (eps, pdf, ...), not pixel-based graphics,
%    for better scaling properties



%% part 5: matlab from command line

% $matlab -nodesktop -nodisplay < input.m > output.m
% example: $matlab -nodesktop -nodisplay < simple_cmd_line.m > dummy.m